﻿--[[
Name: Killers VoiceCommand KeyBindings
Revision: $Rev: 2.0 $
Developed by: Killers Software
Copyright: Copyright© 2008-2010 Killers Software
Website: http://www.killerssoftware.com/
Documentation: http://www.killerssoftware.com/wowaddon.html
Description: Killers VoiceCommand KeyBindings add-on creates a table of all your existing key bindings, action bar items,
             shape shifting action items, and pet action items to create a KillersSoftware.lua variables file 
             that can be imported directly into Killers VoiceCommand Voice Recognition Software.
             
             Go to the Tools\Options\WOW tab to narrow down the items you wish to import into
             Killers VoiceCommand.
             
             To import the KillersSoftware.lua file go to the File\Import menu and browse to the
             SavedVariables folder under WTF\ACCOUNT folder.  KillersSoftware.lua will be located
             int your account SavedVariables folder and in each of your character SavedVariables folder.

Slash Commands:
/createKeyBindings - creates the key bindings
/aboutVoiceCommand - show the about dialog box.

Dependencies: None
]]

local BINDINGS_COUNT = 0;
CharKeystrokeKeyBindings = { };
KeystrokeKeyBindings = { };
local LOADED = false;
local VARIABLES_LOADED = false;
SLASH_ABOUTVOICECOMMAND1 = "/aboutVoiceCommand";
SLASH_CREATEKEYBINDINGS1 = "/createkeybindings";

SlashCmdList["ABOUTVOICECOMMAND"] = function()
  aboutVoiceCommand();
end
SlashCmdList["CREATEKEYBINDINGS"] = function()
  createKeyBindings();
end

function frmMain_OnLoad()
	frameMain:Hide();
   this:RegisterEvent("VARIABLES_LOADED");
   this:RegisterEvent("ADDON_LOADED");
end

function frmMain_OnEvent()
  if (event == "VARIABLES_LOADED") and not VARIABLES_LOADED then
    VARIABLES_LOADED = true;
  end
  if (event == "ADDON_LOADED") and VARIABLES_LOADED then
    this:UnregisterEvent("ADDON_LOADED");
	 showVoiceCommandMessage();
	 print("");
    createKeyBindings();
    LOADED = true;  
  end
end

function showVoiceCommandMessage()
    print("Killers VoiceCommand! KeyBindings v2.0 Add-On by www.KillersSoftware.com");
    print("NOTE: You must have your pet visible in order to create the pet voice commands.");
    print("to create key bindings type /createKeyBindings");
    print("for help type /aboutVoiceCommand");
end

function btnOK_OnClick()
   createKeyBindings();
   frameMain:Hide();
end

function btnCancel_OnClick()
   frameMain:Hide();
end

function aboutVoiceCommand()
  frameMain:Show();
end

function clearTable(tbl)
   local count = table.getn(tbl);
   for x = count, 1, -1 do
     table.remove(tbl);
   end
end

function createKeyBindings()
  BINDINGS_COUNT = 0;
  local numCount = GetNumBindings();
  if (numCount == 0) then
    return;
  end
  
  clearTable(CharKeystrokeKeyBindings);
  clearTable(KeystrokeKeyBindings);
  local keyEntry = {};
  local x = 0;
  local command, key1, key2;
  for x = 1, numCount do
    command, key1, key2 = GetBinding(x);
    keyEntry = {};
    if (command) then
      if (string.sub(command, 1, 7) ~= "HEADER_") then
        if (key1 or key2) then
          BINDINGS_COUNT = BINDINGS_COUNT + 1;
          keyEntry.command = command;
          local voiceCmd, actionType, slot = getActionDescByCommand(command);
          keyEntry.actionType = actionType;
          if (voiceCmd and voiceCmd ~= "") then
            keyEntry.voiceCommand = voiceCmd;
            keyEntry.descBySlot = true;      -- Description by Slot
          else
            keyEntry.voiceCommand = command;
            keyEntry.descBySlot = false;     -- no desc found we will use the ones from the key bindings
          end
          if (key1) then
            keyEntry.key1 = key1;
          end
          if (key2) then
            keyEntry.key2 = key2;
          end
          tinsert(CharKeystrokeKeyBindings, keyEntry);
          tinsert(KeystrokeKeyBindings, keyEntry);
        end;
      end
    end
  end

  createShapeShiftBindings(73, 84);
  createShapeShiftBindings(85, 96);
  createShapeShiftBindings(97, 108);
  
  print("Killers VoiceCommand "..tostring(BINDINGS_COUNT).." KeyBindings found...");
  print("Exit World Of Warcraft to save the KillersSoftware.lua file which will be located under WTF\\ACCOUNT folder");
  print("Go into Tools\\Options\\WOW tab in Killers VoiceCommand to narrow down the items you wish to import into Killers VoiceCommand");
  print("Go into Killers VoiceCommand File\\Import KillersSoftware.lua to import the file into Killers VoiceCommand");

end

function createShapeShiftBindings(startIdx, endIdx)
   local idx = 1;
   local keyEntry = {};
   local command, key1, key2;
   local actionBarIdx = 1;
   local actionBarStr;
   for x = startIdx, endIdx do
     keyEntry = { };
     actionBarStr = "ACTIONBUTTON"..tostring(actionBarIdx);
     keyEntry.command = actionBarStr;
     key1, key2 = GetBindingKey(actionBarStr);
     voiceCmd, actionType, slot = getActionName(x);
     keyEntry.actionType = "shapeshift";
     if (voiceCmd ~= "") then
       keyEntry.voiceCommand = voiceCmd;
       keyEntry.descBySlot = true;
       if (key1) then
         keyEntry.key1 = key1;
       end
       if (key2) then
         keyEntry.key2 = key2;
       end
       BINDINGS_COUNT = BINDINGS_COUNT + 1;
       tinsert(CharKeystrokeKeyBindings, keyEntry);
       tinsert(KeystrokeKeyBindings, keyEntry);
     end
     actionBarIdx = actionBarIdx + 1;
   end
end

function getPetActionName(petSlot)
   local petBar = PetHasActionBar();
   if (petBar) then
     local name, subText, texture, isToken = GetPetActionInfo(petSlot);
     if (name) then
       if (name == "PET_ACTION_ATTACK") then
         name = "pet attack";
         return name, "pet", petSlot;
       end
       if (name == "PET_ACTION_FOLLOW") then
         name = "pet follow";
         return name, "pet", petSlot;
       end
       if (name == "PET_ACTION_WAIT") then
         name = "pet wait";
         return name, "pet", petSlot;
       end
       if (name == "Growl") then
         name = "pet growl";
         return name, "pet", petSlot;
       end
       if (name == "Claw") then
         name = "pet claw";
         return name, "pet", petSlot;
       end
       if (name == "Cower") then
         name = "pet cower";
         return name, "pet", petSlot;
       end
       if (name == "Savage Rend") then
         name = "pet savage rend";
         return name, "pet", petSlot;
       end
       if (name == "PET_MODE_AGGRESSIVE") then
         name = "pet aggressive";
         return name, "pet", petSlot;
       end
       if (name == "PET_MODE_DEFENSIVE") then
         name = "pet defensive";
         return name, "pet", petSlot;
       end
       if (name == "PET_MODE_PASSIVE") then
         name = "pet passive";
         return name, "pet", petSlot;
       end
       return name, "pet", petSlot;
     end
   end
   return "", "", "";
end


function getActionDescByCommand(command)
  if (command) then
    -- Action Button 1 - 12
    if (command == "ACTIONBUTTON1") then
      return getActionName(1); 
    end
    if (command == "ACTIONBUTTON2") then
      return getActionName(2);
    end
    if (command == "ACTIONBUTTON3") then
      return getActionName(3);
    end
    if (command == "ACTIONBUTTON4") then
      return getActionName(4);
    end
    if (command == "ACTIONBUTTON5") then
      return getActionName(5);
    end
    if (command == "ACTIONBUTTON6") then
      return getActionName(6);
    end
    if (command == "ACTIONBUTTON7") then
      return getActionName(7);
    end
    if (command == "ACTIONBUTTON8") then
      return getActionName(8);
    end
    if (command == "ACTIONBUTTON9") then
      return getActionName(9);
    end
    if (command == "ACTIONBUTTON10") then
      return getActionName(10);
    end
    if (command == "ACTIONBUTTON11") then
      return getActionName(11);
    end
    if (command == "ACTIONBUTTON12") then
      return getActionName(12);
    end
    
    -- Pet commands for hunters
    -- Secondary Action Button 1 - 10
    if (command == "BONUSACTIONBUTTON1") then
       return getPetActionName(1);
    end
    if (command == "BONUSACTIONBUTTON2") then
      return getPetActionName(2);
    end
    if (command == "BONUSACTIONBUTTON3") then
      return getPetActionName(3);
    end
    if (command == "BONUSACTIONBUTTON4") then
      return getPetActionName(4);
    end    
    if (command == "BONUSACTIONBUTTON5") then
      return getPetActionName(5);
    end
    if (command == "BONUSACTIONBUTTON6") then
      return getPetActionName(6);
    end    
    if (command == "BONUSACTIONBUTTON7") then
      return getPetActionName(7);
    end
    if (command == "BONUSACTIONBUTTON8") then
      return getPetActionName(8);
    end
    if (command == "BONUSACTIONBUTTON9") then
      return getPetActionName(9);
    end
    if (command == "BONUSACTIONBUTTON10") then
      return getPetActionName(10);
    end    
        
    -- Shapeshiftform
    if (command == "SHAPESHIFTBUTTON1") then
      local texture, name = GetShapeshiftFormInfo(1);
      return name, "shapeshift", 1;
    end
    if (command == "SHAPESHIFTBUTTON2") then
      local texture, name = GetShapeshiftFormInfo(2);
      return name, "shapeshift", 2;
    end
    if (command == "SHAPESHIFTBUTTON3") then
      local texture, name = GetShapeshiftFormInfo(3);
      return name, "shapeshift", 3;
    end
    if (command == "SHAPESHIFTBUTTON4") then
      local texture, name = GetShapeshiftFormInfo(4);
      return name, "shapeshift", 4;
    end
    if (command == "SHAPESHIFTBUTTON5") then
      local texture, name = GetShapeshiftFormInfo(5);
      return name, "shapeshift", 5;
    end
    if (command == "SHAPESHIFTBUTTON6") then
      local texture, name = GetShapeshiftFormInfo(6);
      return name, "shapeshift", 6;
    end
    if (command == "SHAPESHIFTBUTTON7") then
      local texture, name = GetShapeshiftFormInfo(7);
      return name, "shapeshift", 7;
    end
    if (command == "SHAPESHIFTBUTTON8") then
      local texture, name = GetShapeshiftFormInfo(8);
      return name, "shapeshift", 8;
    end
    if (command == "SHAPESHIFTBUTTON9") then
      local texture, name = GetShapeshiftFormInfo(9);
      return name, "shapeshift", 9;
    end
    if (command == "SHAPESHIFTBUTTON10") then
      local texture, name = GetShapeshiftFormInfo(10);
      return name, "shapeshift", 10;
    end
    
    -- Right Action Button 1 - 12
    if (command == "MULTIACTIONBAR3BUTTON1") then
      return getActionName(25);
    end
    if (command == "MULTIACTIONBAR3BUTTON2") then
      return getActionName(26);
    end
    if (command == "MULTIACTIONBAR3BUTTON3") then
      return getActionName(27);
    end     
    if (command == "MULTIACTIONBAR3BUTTON4") then
      return getActionName(28);
    end
    if (command == "MULTIACTIONBAR3BUTTON5") then
      return getActionName(29);
    end
    if (command == "MULTIACTIONBAR3BUTTON6") then
      return getActionName(30);
    end
    if (command == "MULTIACTIONBAR3BUTTON7") then
      return getActionName(31);
    end
    if (command == "MULTIACTIONBAR3BUTTON8") then
      return getActionName(32);
    end
    if (command == "MULTIACTIONBAR3BUTTON9") then
      return getActionName(33);
    end
    if (command == "MULTIACTIONBAR3BUTTON10") then
      return getActionName(34);
    end
    if (command == "MULTIACTIONBAR3BUTTON11") then
      return getActionName(35);
    end
    if (command == "MULTIACTIONBAR3BUTTON12") then
      return getActionName(36);
    end
    
    -- Right Action Bar 2 Button 1 - 12
    if (command == "MULTIACTIONBAR4BUTTON1") then
      return getActionName(37);
    end
    if (command == "MULTIACTIONBAR4BUTTON2") then
      return getActionName(38);
    end
    if (command == "MULTIACTIONBAR4BUTTON3") then
      return getActionName(39);
    end    
    if (command == "MULTIACTIONBAR4BUTTON4") then
      return getActionName(40);
    end
    if (command == "MULTIACTIONBAR4BUTTON5") then
      return getActionName(41);
    end
    if (command == "MULTIACTIONBAR4BUTTON6") then
      return getActionName(42);
    end
    if (command == "MULTIACTIONBAR4BUTTON7") then
      return getActionName(43);
    end
    if (command == "MULTIACTIONBAR4BUTTON8") then
      return getActionName(44);
    end
    if (command == "MULTIACTIONBAR4BUTTON9") then
      return getActionName(45);
    end
    if (command == "MULTIACTIONBAR4BUTTON10") then
      return getActionName(46);
    end
    if (command == "MULTIACTIONBAR4BUTTON11") then
      return getActionName(47);
    end
    if (command == "MULTIACTIONBAR4BUTTON12") then
      return getActionName(48);
    end
    
    -- Bottom Right Action Button 1 - 12
    if (command == "MULTIACTIONBAR2BUTTON1") then
      return getActionName(49);
    end
    if (command == "MULTIACTIONBAR2BUTTON2") then
      return getActionName(50);
    end
    if (command == "MULTIACTIONBAR2BUTTON3") then
      return getActionName(51);
    end
    if (command == "MULTIACTIONBAR2BUTTON4") then
      return getActionName(52);
    end
    if (command == "MULTIACTIONBAR2BUTTON5") then
      return getActionName(53);
    end
    if (command == "MULTIACTIONBAR2BUTTON6") then
      return getActionName(54);
    end
    if (command == "MULTIACTIONBAR2BUTTON7") then
      return getActionName(55);
    end
    if (command == "MULTIACTIONBAR2BUTTON8") then
      return getActionName(56);
    end
    if (command == "MULTIACTIONBAR2BUTTON9") then
      return getActionName(57);
    end
    if (command == "MULTIACTIONBAR2BUTTON10") then
      return getActionName(58);
    end
    if (command == "MULTIACTIONBAR2BUTTON11") then
      return getActionName(59);
    end
    if (command == "MULTIACTIONBAR2BUTTON12") then
      return getActionName(60);
    end
    
    -- Bottom Left Action Button 1 - 12
    if (command == "MULTIACTIONBAR1BUTTON1") then
      return getActionName(61);
    end    
    if (command == "MULTIACTIONBAR1BUTTON2") then
      return getActionName(62);
    end
    if (command == "MULTIACTIONBAR1BUTTON3") then
      return getActionName(63);
    end
    if (command == "MULTIACTIONBAR1BUTTON4") then
      return getActionName(64);
    end
    if (command == "MULTIACTIONBAR1BUTTON5") then
      return getActionName(65);
    end
    if (command == "MULTIACTIONBAR1BUTTON6") then
      return getActionName(66);
    end
    if (command == "MULTIACTIONBAR1BUTTON7") then
      return getActionName(67);
    end
    if (command == "MULTIACTIONBAR1BUTTON8") then
      return getActionName(68);
    end
    if (command == "MULTIACTIONBAR1BUTTON9") then
      return getActionName(69);
    end
    if (command == "MULTIACTIONBAR1BUTTON10") then
      return getActionName(70);
    end
    if (command == "MULTIACTIONBAR1BUTTON11") then
      return getActionName(71);
    end
    if (command == "MULTIACTIONBAR1BUTTON12") then
      return getActionName(72);
    end
    
  end
  return "", "", "";
end

function getActionName(slot)
  local actionType, id, subtype = GetActionInfo(slot);
  local name;
  if ((actionType == "spell") and (id > 0)) then
    name = GetSpellName(id, "spell");
    if (name) then
      return string.lower(name), "spell", slot;
    end
  elseif ((actionType == "item") and (id > 0)) then
    name = GetItemInfo(id);
    if (name) then
      return string.lower(name), "item", slot;
    end
  elseif ((actionType == "macro") and (id > 0)) then
    name = GetMacroItem(id);
--    name = GetMacroBody(id);
    if (name) then
      return string.lower(name), "macro", slot;
    end
  end
  KillersTooltip:SetOwner(UIParent, "ANCHOR_NONE");
  KillersTooltip:SetAction(slot);
  name = KillersTooltipTextLeft1:GetText();
  KillersTooltip:Hide();
  if (name) then
    return string.lower(name), actionType, slot;
  end
  return "", "", "";
end

function print(value)
  if (value) then
    DEFAULT_CHAT_FRAME:AddMessage("" .. value, 1.0, 1.0, 1.0);
  end
end
function sfActionBars_OnUpdate()
   --FauxScrollFrame_Update(sfActionBars, BINDINGS_COUNT, 5, 16);
  --print("We're at "..FauxScrollFrame_GetOffset(sfActionBars));
end
